<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>Há pouco</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 nova mensagem</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minutos atrás</translation>
    </message>
</context>
</TS>